@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: Script to generate buildinfo.json for Plack::App::ServiceStatus
 # PODNAME: plack_app_service_status_generate_buildinfo.pl
-our $VERSION = '0.910'; # VERSION
+our $VERSION = '0.911'; # VERSION
 
 use POSIX qw(strftime);
 use Getopt::Long;
@@ -35,7 +35,7 @@ chdir($project_dir);
 
 my $data = '{';    # just concat the JSON :-)
 
-my $now = strftime( '%FT%TZ', gmtime( time() ) );
+my $now = strftime( '%Y-%m-%dT%H:%M:%SZ', gmtime( time() ) );
 $data .= qq{"date":"$now"};
 
 my $has_git = `git --version`;
@@ -66,7 +66,7 @@ plack_app_service_status_generate_buildinfo.pl - Script to generate buildinfo.js
 
 =head1 VERSION
 
-version 0.910
+version 0.911
 
 =head1 SYNOPSIS
 
