@@ -2,9 +2,9 @@ package Plack::App::ServiceStatus;
 
 # ABSTRACT: Check and report status of various services needed by your app
 
-our $VERSION = '0.910'; # VERSION
+our $VERSION = '0.911'; # VERSION
 
-use 5.018;
+use 5.024;
 use strict;
 use warnings;
 
@@ -84,7 +84,7 @@ sub to_app {
 
         my $json = {
             app                => $self->app,
-            started_at_iso8601 => strftime( '%FT%TZ', gmtime($startup) ),
+            started_at_iso8601 => strftime( '%Y-%m-%dT%H:%M:%SZ', gmtime($startup) ),
             started_at         => $startup,
             uptime             => time() - $startup,
         };
@@ -137,7 +137,7 @@ Plack::App::ServiceStatus - Check and report status of various services needed b
 
 =head1 VERSION
 
-version 0.910
+version 0.911
 
 =head1 SYNOPSIS
 
@@ -296,7 +296,9 @@ Thanks to
 =item * L<validad.com|https://www.validad.com/> for funding the
 development of this code.
 
-=item * <Manfred Stock|https://github.com/mstock> for adding
+=item *
+
+L<Manfred Stock|https://github.com/mstock> for adding
 Net::Stomp and a Icinga/Nagios check script.
 
 =item * L<VÖV / Knowledgebase Erwachsenenbildung|https://adulteducation.at/> for the buildinfo feature.
